@@ -7,10 +7,14 @@ from gbackup import DriverHelper
 import numpy as np
 import subprocess ,json
 
-def upload_file(path):
+def upload_file_old(path):
     public_folder_id = "1kl75TP6zJiuFBdjhJUw1GHhdcIEjueoE"
     file_name = os.path.basename(path)
     return Client("/u02/drive_config/public_config/coca_idrive.json", "upload", path, "").upload_file(file_name,path, public_folder_id)
+def upload_file(path):
+    dh = DriverHelper()
+    x = dh.upload_file("result@soundhex.com", path)
+    return x.replace("gdrive;;result@soundhex.com;;","")
 def remove(path):
     try:
         os.remove(path)
