@@ -56,18 +56,24 @@ class MyBarLogger(ProgressBarLogger):
 
 
 def create_lyric_outro(deezer_artist_id, lyric_outro_repeat,  arr_comp, time_o=5):
-    outro_sound = MusicHelper.create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat)
-    path_video = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid-audio.mp4")
-    tmp_path_composite_outro = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid.mp4")
-    tmp_clip = CompositeVideoClip(arr_comp).subclip(0, time_o)
-    tmp_clip.write_videofile(tmp_path_composite_outro, bitrate='4M', fps=24, codec='libx264', audio=False)
-    tmp_clip.close()
-
-    audio_compilation = AudioFileClip(outro_sound)
-    final_clip_path = create_loop(tmp_path_composite_outro, audio_compilation.duration)
-    utils.remove(tmp_path_composite_outro)
-    audio_compilation.close()
-    create_video_audio(final_clip_path, outro_sound, path_video)
+    if deezer_artist_id == 977996688:
+        return None
+    path_video = None
+    try:
+        outro_sound = MusicHelper.create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat)
+        path_video = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid-audio.mp4")
+        tmp_path_composite_outro = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid.mp4")
+        tmp_clip = CompositeVideoClip(arr_comp).subclip(0, time_o)
+        tmp_clip.write_videofile(tmp_path_composite_outro, bitrate='4M', fps=24, codec='libx264', audio=False)
+        tmp_clip.close()
+        audio_compilation = AudioFileClip(outro_sound)
+        final_clip_path = create_loop(tmp_path_composite_outro, audio_compilation.duration)
+        utils.remove(tmp_path_composite_outro)
+        audio_compilation.close()
+        create_video_audio(final_clip_path, outro_sound, path_video)
+    except:
+        path_video = None
+        pass
     return path_video
 def create_video(list_comp_data, path_video, job_id, mf_server):
     print('get list')
